@@ -48,12 +48,12 @@ void CegoAVLIndexManager::insertNativeIndexTable(CegoTableObject& ioe,
 					      const CegoDataPointer& sysEntry, 
 					      const CegoDataPointer& dp,
 					      char* idxPtr, 
-					      int idxLen, 
+					      unsigned idxLen, 
 					      unsigned long long tid, 
 					      bool insertAtLastPage,
 					      CegoDataPointer& ritp)
 {
-    int tabSetId = ioe.getTabSetId();
+    unsigned tabSetId = ioe.getTabSetId();
     Chain indexName = ioe.getName();
     Chain tabName = ioe.getTabName();
 
@@ -70,7 +70,7 @@ void CegoAVLIndexManager::insertNativeIndexTable(CegoTableObject& ioe,
     
     CegoDataPointer rdp;
     char* p;
-    int len;
+    unsigned len;
 
     p = (char*)pC->getFirst(len, rdp);
     
@@ -158,7 +158,7 @@ void CegoAVLIndexManager::insertIndexTable(CegoTableObject& ioe,
 					bool isUnique, 
 					const CegoDataPointer& dp, 
 					char* idxPtr, 
-					int idxLen, 
+					unsigned idxLen, 
 					unsigned long long tid,
 					bool insertAtLastPage, 
 					bool allowWrite)
@@ -166,11 +166,11 @@ void CegoAVLIndexManager::insertIndexTable(CegoTableObject& ioe,
     if ( _lockId == 0 )
 	_lockId = _pTM->getLockHandler()->lockData(CegoObject::BTREE, ritp.getPageId(), CegoLockHandler::WRITE);
           
-    int tabSetId = ioe.getTabSetId();
+    unsigned tabSetId = ioe.getTabSetId();
     ListT<CegoField> schema = ioe.getSchema();
  
     char* p;
-    int len;
+    unsigned len;
 
     CegoBufferPool::FixMode fixMode;
 
@@ -197,11 +197,10 @@ void CegoAVLIndexManager::insertIndexTable(CegoTableObject& ioe,
 
     CegoAVLIndexEntry ie;
 
-    int level = 0;
+    unsigned level = 0;
     
     while ( ! inserted )
     {
-	
 	ie.setPtr(p, len);
 	bool leftBranch = false;
 	
@@ -259,17 +258,13 @@ void CegoAVLIndexManager::insertIndexTable(CegoTableObject& ioe,
 		{
 		    _pTM->releaseDataPtrUnlocked(rootPage, false);		    
 		    _pTM->releaseDataPtrUnlocked(pageIE, false);
-
-		    throw Exception(EXLOC, Chain("Duplicate index key on unique index ") + ioe.getName() );
-		    		    
+		    throw Exception(EXLOC, Chain("Duplicate index key on unique index ") + ioe.getName() );		    	
 		}
 	    }	  
 	    else
-	    {
-		
+	    {		
 		_pTM->releaseDataPtrUnlocked(rootPage, false);
-		_pTM->releaseDataPtrUnlocked(pageIE, false);
-		
+		_pTM->releaseDataPtrUnlocked(pageIE, false);		
 		throw Exception(EXLOC, Chain("Duplicate index key on unique index ") + ioe.getName() );
 	    }
 	}  
@@ -309,7 +304,6 @@ void CegoAVLIndexManager::insertIndexTable(CegoTableObject& ioe,
 	    
 	    if (leftBranch)
 	    {
-
 		ie.setLeftBranch(dp);
 		if (ie.getHeight() == 1 )
 		{
@@ -323,7 +317,6 @@ void CegoAVLIndexManager::insertIndexTable(CegoTableObject& ioe,
 	    }
 	    else
 	    {
-
 		ie.setRightBranch(dp);
 		
 		if (ie.getHeight() == 1)
@@ -496,10 +489,10 @@ void CegoAVLIndexManager::insertIndexTable(CegoTableObject& ioe,
     }
 }
 
-void CegoAVLIndexManager::getSubTreeHeight(int tabSetId, CegoBufferPool::FixMode fixMode, const CegoAVLIndexEntry& pe, char& leftHeight, char& rightHeight)
+void CegoAVLIndexManager::getSubTreeHeight(unsigned tabSetId, CegoBufferPool::FixMode fixMode, const CegoAVLIndexEntry& pe, char& leftHeight, char& rightHeight)
 {
     char* p;
-    int len;
+    unsigned len;
     CegoDataPointer nil;
     
     CegoDataPointer ldp = pe.getLeftBranch();
@@ -537,7 +530,7 @@ void CegoAVLIndexManager::getSubTreeHeight(int tabSetId, CegoBufferPool::FixMode
     return;
 }    
 
-void CegoAVLIndexManager::deleteIndexTable(int tabSetId, const Chain& tableName, CegoObject::ObjectType tabType, const Chain& indexName, CegoObject::ObjectType idxType, const ListT<CegoField>& schema, const CegoDataPointer& ddp, char* idxPtr, int idxLen, bool allowWrite)
+void CegoAVLIndexManager::deleteIndexTable(unsigned tabSetId, const Chain& tableName, CegoObject::ObjectType tabType, const Chain& indexName, CegoObject::ObjectType idxType, const ListT<CegoField>& schema, const CegoDataPointer& ddp, char* idxPtr, unsigned idxLen, bool allowWrite)
 {    
 
     CegoBufferPool::FixMode fixMode;
@@ -560,7 +553,7 @@ void CegoAVLIndexManager::deleteIndexTable(int tabSetId, const Chain& tableName,
 
     CegoDataPointer rdp;
     char* p;
-    int len;
+    unsigned len;
     p = (char*)pC->getFirst(len, rdp);
     
     if ( p == 0 )
@@ -1206,9 +1199,9 @@ void CegoAVLIndexManager::deleteIndexTable(int tabSetId, const Chain& tableName,
 	    while ( pF )
 	    {
 				
-		int flen;
-		memcpy(&flen, p, sizeof(int));
-		p += sizeof(int);
+		unsigned flen;
+		memcpy(&flen, p, sizeof(unsigned));
+		p += sizeof(unsigned);
 		
 		CegoFieldValue fv;
 		fv.setLength(flen);
@@ -1239,10 +1232,10 @@ void CegoAVLIndexManager::deleteIndexTable(int tabSetId, const Chain& tableName,
     _pTM->releaseDataPtrUnlocked(rootPage, false);   
 }
 
-void CegoAVLIndexManager::propagateDecrease(int tabSetId, CegoDataPointer itp, CegoBufferPool::FixMode fixMode)
+void CegoAVLIndexManager::propagateDecrease(unsigned tabSetId, CegoDataPointer itp, CegoBufferPool::FixMode fixMode)
 {
     char* p;
-    int len;
+    unsigned len;
 
     CegoBufferPage pageIE;
     _pTM->claimDataPtrUnlocked(tabSetId, fixMode, itp, p, len, pageIE);
@@ -1342,10 +1335,10 @@ void CegoAVLIndexManager::propagateDecrease(int tabSetId, CegoDataPointer itp, C
 	_pTM->releaseDataPtrUnlocked(pagePE, true);    
 }
 
-CegoDataPointer CegoAVLIndexManager::rebalanceNode(int tabSetId, CegoDataPointer itp, CegoBufferPool::FixMode fixMode)
+CegoDataPointer CegoAVLIndexManager::rebalanceNode(unsigned tabSetId, CegoDataPointer itp, CegoBufferPool::FixMode fixMode)
 {
     char* p;
-    int len;
+    unsigned len;
 
     CegoDataPointer nil;
 
@@ -1441,12 +1434,12 @@ CegoAVLIndexManager::TupleOrder CegoAVLIndexManager::compIndexValue(const ListT<
     while ( pF )
     {
        
-	int flen1, flen2;
-	memcpy(&flen1, p1, sizeof(int));
-	memcpy(&flen2, p2, sizeof(int));
+	unsigned flen1, flen2;
+	memcpy(&flen1, p1, sizeof(unsigned));
+	memcpy(&flen2, p2, sizeof(unsigned));
 
-	p1 += sizeof(int);
-	p2 += sizeof(int);
+	p1 += sizeof(unsigned);
+	p2 += sizeof(unsigned);
 	
 	CegoFieldValue fv1, fv2;
 	fv1.setLength(flen1);
@@ -1488,10 +1481,10 @@ CegoAVLIndexManager::TupleOrder CegoAVLIndexManager::compIndexValue(const ListT<
     return EQU;
 }
 
-CegoDataPointer CegoAVLIndexManager::rotateRR(int tabSetId, const CegoDataPointer& ptp, CegoBufferPool::FixMode fixMode)
+CegoDataPointer CegoAVLIndexManager::rotateRR(unsigned tabSetId, const CegoDataPointer& ptp, CegoBufferPool::FixMode fixMode)
 {
     char *p;
-    int len;
+    unsigned len;
 
     CegoDataPointer itp, atp, ctp;
     CegoAVLIndexEntry pe, ie, ae, ce;
@@ -1588,10 +1581,10 @@ CegoDataPointer CegoAVLIndexManager::rotateRR(int tabSetId, const CegoDataPointe
 }
 
 
-CegoDataPointer CegoAVLIndexManager::rotateRL(int tabSetId, const CegoDataPointer& ptp, CegoBufferPool::FixMode fixMode)
+CegoDataPointer CegoAVLIndexManager::rotateRL(unsigned tabSetId, const CegoDataPointer& ptp, CegoBufferPool::FixMode fixMode)
 {
     char *p;
-    int len;
+    unsigned len;
     
     CegoDataPointer itp, atp, ctp, etp, ftp;
     CegoAVLIndexEntry pe, ie, ae, ce, ee, fe;
@@ -1733,10 +1726,10 @@ CegoDataPointer CegoAVLIndexManager::rotateRL(int tabSetId, const CegoDataPointe
 }
 
 
-CegoDataPointer CegoAVLIndexManager::rotateLL(int tabSetId, const CegoDataPointer& ptp, CegoBufferPool::FixMode fixMode)
+CegoDataPointer CegoAVLIndexManager::rotateLL(unsigned tabSetId, const CegoDataPointer& ptp, CegoBufferPool::FixMode fixMode)
 {
     char *p;
-    int len;
+    unsigned len;
     
     CegoDataPointer itp, atp, dtp;
     CegoAVLIndexEntry pe, ie, ae, de;
@@ -1836,10 +1829,10 @@ CegoDataPointer CegoAVLIndexManager::rotateLL(int tabSetId, const CegoDataPointe
     return itp;
 } 
 
-CegoDataPointer CegoAVLIndexManager::rotateLR(int tabSetId, const CegoDataPointer& ptp, CegoBufferPool::FixMode fixMode)
+CegoDataPointer CegoAVLIndexManager::rotateLR(unsigned tabSetId, const CegoDataPointer& ptp, CegoBufferPool::FixMode fixMode)
 {
     char *p;
-    int len;
+    unsigned len;
         
     CegoDataPointer itp, atp, ctp, dtp, etp;
     CegoAVLIndexEntry pe, ie, ae, ce, de, ee;
@@ -1980,7 +1973,7 @@ CegoDataPointer CegoAVLIndexManager::rotateLR(int tabSetId, const CegoDataPointe
     return dtp;
 }
 
-char CegoAVLIndexManager::checkIndex(int tabSetId, const Chain& indexName, CegoObject::ObjectType idxType)
+char CegoAVLIndexManager::checkIndex(unsigned tabSetId, const Chain& indexName, CegoObject::ObjectType idxType)
 {
     CegoTableObject oe;
     _pTM->getObject(tabSetId, indexName, idxType, oe);
@@ -1995,7 +1988,7 @@ char CegoAVLIndexManager::checkIndex(int tabSetId, const Chain& indexName, CegoO
 
     CegoDataPointer rdp;
     char* p;
-    int len;
+    unsigned len;
     p = (char*)pC->getFirst(len, rdp);
     
     if ( p == 0 )
@@ -2025,7 +2018,7 @@ char CegoAVLIndexManager::checkIndex(int tabSetId, const Chain& indexName, CegoO
     return h;
 }
 
-char CegoAVLIndexManager::recursiveIndexNodeCheck(int tabSetId, const CegoDataPointer& dp)
+char CegoAVLIndexManager::recursiveIndexNodeCheck(unsigned tabSetId, const CegoDataPointer& dp)
 {
     CegoDataPointer nil;
 
@@ -2033,7 +2026,7 @@ char CegoAVLIndexManager::recursiveIndexNodeCheck(int tabSetId, const CegoDataPo
 	return 0;
     
     char* p;
-    int len;
+    unsigned len;
 
 #ifdef CGDEBUG
     _pLogger->log(_modId, Logger::DEBUG, Chain("Claiming datapointer ") +  dp.toChain());
@@ -2087,7 +2080,7 @@ char CegoAVLIndexManager::recursiveIndexNodeCheck(int tabSetId, const CegoDataPo
     return nodeHeight;
 }
 
-CegoDataPointer CegoAVLIndexManager::searchDataPointer(int tabSetId, const CegoDataPointer& ddp, const CegoDataPointer& rdp, CegoBufferPool::FixMode fixMode)
+CegoDataPointer CegoAVLIndexManager::searchDataPointer(unsigned tabSetId, const CegoDataPointer& ddp, const CegoDataPointer& rdp, CegoBufferPool::FixMode fixMode)
 {
     CegoDataPointer itp;
 
@@ -2097,7 +2090,7 @@ CegoDataPointer CegoAVLIndexManager::searchDataPointer(int tabSetId, const CegoD
 	return nil;
 
     char* p;
-    int len;
+    unsigned len;
          
     CegoBufferPage pageRE;
     _pTM->claimDataPtrUnlocked(tabSetId, fixMode, rdp, p, len, pageRE);  
