@@ -18,6 +18,7 @@
 //
 ///////////////////////////////////////////////////////////////////////////////
 
+
 #include <lfcbase/Tokenizer.h>
 #include <lfcbase/Host.h>
 #include <lfcbase/Datetime.h>
@@ -337,7 +338,7 @@ void CegoAdmAction::showQueryCacheAction()
     CegoAdminHandler::ResultType res;
 
     res = _pAH->reqShowQueryCache(tableSet);
-    handleMedResult(res);
+    handleResult(res);
     
     CegoTableObject oe;
     ListT<ListT<CegoFieldValue> > info;
@@ -369,7 +370,7 @@ void CegoAdmAction::listQueryCacheAction()
     CegoAdminHandler::ResultType res;
 
     res = _pAH->reqListQueryCache(tableSet);
-    handleMedResult(res);
+    handleResult(res);
     
     CegoTableObject oe;
     ListT<ListT<CegoFieldValue> > info;
@@ -401,7 +402,7 @@ void CegoAdmAction::cleanQueryCacheAction()
     CegoAdminHandler::ResultType res;
 
     res = _pAH->reqCleanQueryCache(tableSet);
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -422,7 +423,7 @@ void CegoAdmAction::setQueryCacheParamAction()
     CegoAdminHandler::ResultType res;
 
     res = _pAH->reqSetQueryCacheParam(tableSet, _maxEntry, _maxSize, _threshold, _hashRange);
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -479,7 +480,7 @@ void CegoAdmAction::showTableCacheAction()
     CegoAdminHandler::ResultType res;
 
     res = _pAH->reqShowTableCache(tableSet);
-    handleMedResult(res);
+    handleResult(res);
     
     CegoTableObject oe;
     ListT<ListT<CegoFieldValue> > info;
@@ -509,7 +510,7 @@ void CegoAdmAction::listTableCacheAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqListTableCache(tableSet);
-    handleMedResult(res);
+    handleResult(res);
     
     CegoTableObject oe;
     ListT<ListT<CegoFieldValue> > info;
@@ -541,7 +542,7 @@ void CegoAdmAction::cleanTableCacheAction()
     CegoAdminHandler::ResultType res;
 
     res = _pAH->reqCleanTableCache(tableSet);
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -562,7 +563,7 @@ void CegoAdmAction::setTableCacheParamAction()
     CegoAdminHandler::ResultType res;
 
     res = _pAH->reqSetTableCacheParam(tableSet, _cacheFilter, _maxEntry, _maxSize, _hashRange);
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -608,8 +609,6 @@ void CegoAdmAction::setTableCacheFilter()
 
 void CegoAdmAction::setDefault()
 {
-    _primary = DEFPRIMARY;
-    _secondary = DEFSECONDARY;
     _tsRoot = DEFTSROOT;
     _logSize = DEFLOGSIZE;
     _logNum = DEFLOGNUM;
@@ -692,7 +691,7 @@ void CegoAdmAction::lockInfoAction()
 	
 	res = _pAH->reqLockInfo(lockCat);
 
-	handleMedResult(res);
+	handleResult(res);
 	
 	Chain msg;
 	_pAH->getMsg(msg);
@@ -715,7 +714,7 @@ void CegoAdmAction::lockStatAction()
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqLockStat();    
-    handleMedResult(res);    
+    handleResult(res);    
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -737,7 +736,7 @@ void CegoAdmAction::poolInfoAction()
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqPoolInfo();
-    handleMedResult(res);    
+    handleResult(res);    
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -767,7 +766,7 @@ void CegoAdmAction::parameterInfoAction()
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqParameterInfo();
-    handleMedResult(res); 
+    handleResult(res); 
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -824,35 +823,12 @@ void CegoAdmAction::poolEntryListAction()
     }
 }
 
-void CegoAdmAction::dbSessionInfoAction() 
-{       
-    CegoAdminHandler::ResultType res;
-    
-    res = _pAH->reqDbSessionInfo();
-    handleMedResult(res);
-
-    Chain msg;
-    _pAH->getMsg(msg);
-    
-    CegoTableObject oe;
-    ListT<ListT<CegoFieldValue> > info;
-    
-    _pAH->getDbSessionInfo(oe, info);
-    
-    CegoOutput output(oe.getSchema());
-    output.setRawMode(_rawMode);
-    output.tabOut(info);
-    
-    if ( _rawMode == false )
-	cout << msg << endl;
-}
-
 void CegoAdmAction::listTableSetAction() 
 {       
     CegoAdminHandler::ResultType res;
     
-    res = _pAH->medGetTableSetList(true);
-    handleMedResult(res);
+    res = _pAH->reqGetTableSetList(true);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -874,7 +850,7 @@ void CegoAdmAction::threadInfoAction()
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqThreadInfo();
-    handleMedResult(res);	
+    handleResult(res);	
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -897,7 +873,7 @@ void CegoAdmAction::dbThreadInfoAction()
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqDbThreadInfo();	
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -928,7 +904,7 @@ void CegoAdmAction::dbThreadQueryHistAction()
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqDbThreadHistory(threadId);
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -959,7 +935,7 @@ void CegoAdmAction::dbQueryHistLastAction()
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqQueryHistoryLast(numLast);
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -990,7 +966,7 @@ void CegoAdmAction::dbQueryHistCostAction()
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqQueryHistoryCost(numLast);
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -1013,7 +989,7 @@ void CegoAdmAction::admThreadInfoAction()
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqAdmThreadInfo();
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -1031,51 +1007,6 @@ void CegoAdmAction::admThreadInfoAction()
 	cout << msg << endl;
 }
 
-void CegoAdmAction::logThreadInfoAction() 
-{       
-    CegoAdminHandler::ResultType res;
-    
-    res = _pAH->reqLogThreadInfo();
-    handleMedResult(res);
-
-    Chain msg;
-    _pAH->getMsg(msg);
-    
-    CegoTableObject oe;
-    ListT<ListT<CegoFieldValue> > info;
-    
-    Chain format;
-    _pAH->getLogThreadInfo(oe, info, format);
-    
-    CegoOutput output(oe.getSchema(), format);
-    output.setRawMode(_rawMode);
-    output.tabOut(info);
-    if ( _rawMode == false )
-	cout << msg << endl;
-}
-
-void CegoAdmAction::copyInfoAction() 
-{       
-    CegoAdminHandler::ResultType res;
-    
-    res = _pAH->reqCopyInfo();
-    handleMedResult(res);
-
-    Chain msg;
-    _pAH->getMsg(msg);
-    
-    CegoTableObject oe;
-    ListT<ListT<CegoFieldValue> > info;
-    
-    Chain format;
-    _pAH->getCopyInfo(oe, info, format);
-    
-    CegoOutput output(oe.getSchema(), format);
-    output.setRawMode(_rawMode);
-    output.tabOut(info);
-    if ( _rawMode == false )
-	cout << msg << endl;	
-}
 
 void CegoAdmAction::buFileInfoAction()
 {
@@ -1090,8 +1021,8 @@ void CegoAdmAction::buFileInfoAction()
 
     CegoAdminHandler::ResultType res;
     
-    res = _pAH->medGetDetailedTableSetInfo(tableSet);
-    handleMedResult(res);
+    res = _pAH->reqGetDetailedTSInfo(tableSet);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -1122,8 +1053,8 @@ void CegoAdmAction::buStatInfoAction()
 
     CegoAdminHandler::ResultType res;
     
-    res = _pAH->medGetBUStatInfo(tableSet);
-    handleMedResult(res);
+    res = _pAH->reqGetBUStatInfo(tableSet);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -1154,8 +1085,8 @@ void CegoAdmAction::buStatResetAction()
 
     CegoAdminHandler::ResultType res;
     
-    res = _pAH->medResetBUStat(tableSet);
-    handleMedResult(res);
+    res = _pAH->reqResetBUStat(tableSet);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -1173,7 +1104,7 @@ void CegoAdmAction::abortDbThreadAction()
     }
     CegoAdminHandler::ResultType res;
     res = _pAH->reqDbThreadAbort(threadId);
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -1181,19 +1112,6 @@ void CegoAdmAction::abortDbThreadAction()
 	cout << msg << endl;
 }
 
-void CegoAdmAction::retrieveTableSetAction()
-{
-    Chain masterHost(_stringBuf);
-    CegoAdminHandler::ResultType res;
-    res = _pAH->reqRetrieveTableSet(masterHost);	
-    handleMedResult(res);
-
-    Chain msg;
-    _pAH->getMsg(msg);
-    if ( _rawMode == false )
-	cout << msg << endl;
-} 
-
 void CegoAdmAction::defineTableSetAction() 
 {
     Chain tableSet;
@@ -1203,10 +1121,8 @@ void CegoAdmAction::defineTableSetAction()
 	tableSet = *pS;
     }
     CegoAdminHandler::ResultType res;
-    res = _pAH->medDefineTableSet(tableSet,
+    res = _pAH->reqDefineTableSet(tableSet,
 				  _tsRoot,
-				  _primary,
-				  _secondary,
 				  _sysSize,
 				  _tmpSize,
 				  _appSize,
@@ -1214,7 +1130,7 @@ void CegoAdmAction::defineTableSetAction()
 				  _logNum, 
 				  _sortAreaSize,
 				  _branchId);
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -1233,13 +1149,13 @@ void CegoAdmAction::startTableSetAction()
 	tableSet = *pS;
     }
     CegoAdminHandler::ResultType res;
-    res = _pAH->medStartTableSet(tableSet, _doCleanup, _doForceload, _doCPDump, _doNoInit);
+    res = _pAH->reqStartTableSet(tableSet, _doCleanup, _doForceload, _doCPDump, _doNoInit);
     _doCleanup=false;
     _doForceload=false;
     _doCPDump=false;
     _doNoInit = false;
 
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -1256,8 +1172,8 @@ void CegoAdmAction::stopTableSetAction()
 	tableSet = *pS;
     }
     CegoAdminHandler::ResultType res;    
-    res = _pAH->medStopTableSet(tableSet);
-    handleMedResult(res);
+    res = _pAH->reqStopTableSet(tableSet);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -1265,17 +1181,17 @@ void CegoAdmAction::stopTableSetAction()
 	cout << msg << endl;
 }
 
-void CegoAdmAction::copyTableSetAction() 
+void CegoAdmAction::startRecoveryAction() 
 {
-    CegoAdminHandler::ResultType res;
     Chain tableSet;
     Chain* pS = getTokenList().First();
     if ( pS )
     {
 	tableSet = *pS;
     }
-    res = _pAH->medCopyTableSet(tableSet);
-    handleMedResult(res);
+    CegoAdminHandler::ResultType res;
+    res = _pAH->reqStartRecovery(tableSet);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -1283,17 +1199,17 @@ void CegoAdmAction::copyTableSetAction()
 	cout << msg << endl;
 }
 
-void CegoAdmAction::switchTableSetAction() 
+void CegoAdmAction::stopRecoveryAction() 
 {
-    CegoAdminHandler::ResultType res;
     Chain tableSet;
     Chain* pS = getTokenList().First();
     if ( pS )
     {
 	tableSet = *pS;
     }
-    res = _pAH->medSwitchTableSet(tableSet);
-    handleMedResult(res);
+    CegoAdminHandler::ResultType res;    
+    res = _pAH->reqStopRecovery(tableSet);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -1301,6 +1217,7 @@ void CegoAdmAction::switchTableSetAction()
 	cout << msg << endl;
 }
 
+
 void CegoAdmAction::dropTableSetAction() 
 {
     CegoAdminHandler::ResultType res;   
@@ -1310,8 +1227,8 @@ void CegoAdmAction::dropTableSetAction()
     {
 	tableSet = *pS;
     }
-    res = _pAH->medDropTableSet(tableSet);
-    handleMedResult(res);
+    res = _pAH->reqDropTableSet(tableSet);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -1328,26 +1245,8 @@ void CegoAdmAction::removeTableSetAction()
     {
 	tableSet = *pS;
     }
-    res = _pAH->medRemoveTableSet(tableSet);
-    handleMedResult(res);
-
-    Chain msg;
-    _pAH->getMsg(msg);
-    if ( _rawMode == false )
-	cout << msg << endl;
-}
-
-void CegoAdmAction::resetTableSetAction() 
-{
-    CegoAdminHandler::ResultType res;   
-    Chain tableSet;
-    Chain* pS = getTokenList().First();
-    if ( pS )
-    {
-	tableSet = *pS;
-    }
-    res = _pAH->medResetTableSet(tableSet);
-    handleMedResult(res);
+    res = _pAH->reqRemoveTableSet(tableSet);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -1364,8 +1263,8 @@ void CegoAdmAction::createTableSetAction()
     {
 	tableSet = *pS;
     }
-    res = _pAH->medCreateTableSet(tableSet);
-    handleMedResult(res);
+    res = _pAH->reqCreateTableSet(tableSet);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -1385,7 +1284,7 @@ void CegoAdmAction::syncTableSetAction()
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSyncTableSet(tableSet, _buMsg, _syncCmd, _timeout);
 
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -1402,8 +1301,8 @@ void CegoAdmAction::beginBackupAction()
 	tableSet = *pS;
     }
     CegoAdminHandler::ResultType res;
-    res = _pAH->medBeginBackup(tableSet, _buMsg);
-    handleMedResult(res);
+    res = _pAH->reqBeginBackup(tableSet, _buMsg);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -1420,8 +1319,8 @@ void CegoAdmAction::executeBackupAction()
 	tableSet = *pS;
     }
     CegoAdminHandler::ResultType res;
-    res = _pAH->medExecuteBackup(tableSet, _buMsg);
-    handleMedResult(res);
+    res = _pAH->reqExecuteBackup(tableSet, _buMsg);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -1438,9 +1337,9 @@ void CegoAdmAction::endBackupAction()
 	tableSet = *pS;
     }
     CegoAdminHandler::ResultType res;
-    res = _pAH->medEndBackup(tableSet, _buMsg, _keepTicket);
+    res = _pAH->reqEndBackup(tableSet, _buMsg, _keepTicket);
     _keepTicket = false;
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -1457,8 +1356,8 @@ void CegoAdmAction::listBackupAction()
 	tableSet = *pS;
     }
     CegoAdminHandler::ResultType res;
-    res = _pAH->medListBackup(tableSet, _pit);
-    handleMedResult(res);
+    res = _pAH->reqListBackup(tableSet, _pit);
+    handleResult(res);
 
     // reset pit to 0
     _pit = Chain();
@@ -1552,8 +1451,8 @@ void CegoAdmAction::restoreTableSetAction()
     }
     
     CegoAdminHandler::ResultType res;
-    res = _pAH->medRestore(tableSet, backupId);
-    handleMedResult(res);
+    res = _pAH->reqRestore(tableSet, backupId);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -1570,8 +1469,8 @@ void CegoAdmAction::recoverTableSetAction()
 	tableSet = *pS;
     }
     CegoAdminHandler::ResultType res;
-    res = _pAH->medRecover(tableSet, _pit, _lsn);
-    handleMedResult(res);
+    res = _pAH->reqRecover(tableSet, _pit, _lsn);
+    handleResult(res);
 
     // reset pit to 0
     _pit = Chain();
@@ -1589,7 +1488,7 @@ void CegoAdmAction::setLogMngAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSetLogMng(progName, _timeout);
-    handleMedResult(res);
+    handleResult(res);
     
     Chain msg;
     _pAH->getMsg(msg);
@@ -1605,7 +1504,7 @@ void CegoAdmAction::setBackupMngAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSetBackupMng(progName);
-    handleMedResult(res);
+    handleResult(res);
     
     Chain msg;
     _pAH->getMsg(msg);
@@ -1689,7 +1588,7 @@ void CegoAdmAction::setTSInitFileAction()
     }
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSetTSInitFile(tableSet, initFileName);
-    handleMedResult(res);
+    handleResult(res);
     
     Chain msg;
     _pAH->getMsg(msg);
@@ -1710,7 +1609,7 @@ void CegoAdmAction::setTSRootPathAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSetTSRootPath(tableSet, tsRoot);
-    handleMedResult(res);
+    handleResult(res);
     
     Chain msg;
     _pAH->getMsg(msg);
@@ -1737,7 +1636,7 @@ void CegoAdmAction::setTSLogNumAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSetTSLogNum(tableSet, logNum);
-    handleMedResult(res);
+    handleResult(res);
     
     Chain msg;
     _pAH->getMsg(msg);
@@ -1763,7 +1662,7 @@ void CegoAdmAction::setTSLogSizeAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSetTSLogSize(tableSet, logSize);
-    handleMedResult(res);
+    handleResult(res);
     
     Chain msg;
     _pAH->getMsg(msg);
@@ -1789,7 +1688,7 @@ void CegoAdmAction::setTSSortAreaSizeAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSetTSSortAreaSize(tableSet, sortAreaSize);
-    handleMedResult(res);
+    handleResult(res);
     
     Chain msg;
     _pAH->getMsg(msg);
@@ -1815,7 +1714,7 @@ void CegoAdmAction::setTSLogUserAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSetTSLogUser(tableSet, logUser);
-    handleMedResult(res);
+    handleResult(res);
     
     Chain msg;
     _pAH->getMsg(msg);
@@ -1841,7 +1740,7 @@ void CegoAdmAction::setTSSysSizeAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSetTSSysSize(tableSet, sysSize);
-    handleMedResult(res);
+    handleResult(res);
     
     Chain msg;
     _pAH->getMsg(msg);
@@ -1867,7 +1766,7 @@ void CegoAdmAction::setTSTmpSizeAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSetTSTmpSize(tableSet, tmpSize);
-    handleMedResult(res);
+    handleResult(res);
     
     Chain msg;
     _pAH->getMsg(msg);
@@ -1893,7 +1792,7 @@ void CegoAdmAction::setTSAppSizeAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSetTSAppSize(tableSet, appSize);
-    handleMedResult(res);
+    handleResult(res);
     
     Chain msg;
     _pAH->getMsg(msg);
@@ -1919,7 +1818,7 @@ void CegoAdmAction::setCheckpointAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSetCheckpoint(tableSet, interval);
-    handleMedResult(res);
+    handleResult(res);
     
     Chain msg;
     _pAH->getMsg(msg);
@@ -1938,7 +1837,7 @@ void CegoAdmAction::setNumQueryLastAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqNumQueryLast(numLast);
-    handleMedResult(res);
+    handleResult(res);
     
     Chain msg;
     _pAH->getMsg(msg);
@@ -1957,7 +1856,7 @@ void CegoAdmAction::setNumQueryCostAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqNumQueryCost(numCost);
-    handleMedResult(res);
+    handleResult(res);
     
     Chain msg;
     _pAH->getMsg(msg);
@@ -1965,108 +1864,6 @@ void CegoAdmAction::setNumQueryCostAction()
 	cout << msg << endl;
 }
 
-void CegoAdmAction::switchSecondaryAction()
-{
-    Chain tableSet;
-    Chain* pS = getTokenList().First();
-    if ( pS )
-    {
-	tableSet = *pS;
-    }
-    
-    CegoAdminHandler::ResultType res;
-    res = _pAH->medSecSwitch(tableSet);
-    handleMedResult(res);
-
-    Chain msg;
-    _pAH->getMsg(msg);
-    if ( _rawMode == false )
-	cout << msg << endl;
-}
-
-void CegoAdmAction::switchMediatorAction()
-{
-    Chain tableSet;
-    Chain* pS = getTokenList().First();
-    if ( pS )
-    {
-	tableSet = *pS;
-    }
-    
-    CegoAdminHandler::ResultType res;
-    res = _pAH->secMedSwitch(tableSet);
-    handleMedResult(res);
-
-    Chain msg;
-    _pAH->getMsg(msg);
-    if ( _rawMode == false )
-	cout << msg << endl;
-}
-
-void CegoAdmAction::relocateSecondaryAction()
-{
-    Chain secondary(_stringBuf);
-    Chain tableSet;
-    Chain* pS = getTokenList().First();
-    pS = getTokenList().Next();
-    pS = getTokenList().Next();
-    if ( pS )
-    {
-	tableSet = *pS;
-    }
-
-    CegoAdminHandler::ResultType res;
-    res = _pAH->medSecRelocate(tableSet, secondary);
-    handleMedResult(res);
-
-    Chain msg;
-    _pAH->getMsg(msg);
-    if ( _rawMode == false )
-	cout << msg << endl;
-}
-
-void CegoAdmAction::relocateMediatorAction()
-{
-    Chain mediator(_stringBuf);
-    Chain tableSet;
-    Chain* pS = getTokenList().First();
-    pS = getTokenList().Next();
-    pS = getTokenList().Next();
-    if ( pS )
-    {
-	tableSet = *pS;
-    }
-    
-    CegoAdminHandler::ResultType res;
-    res = _pAH->secMedRelocate(tableSet, mediator);
-    handleMedResult(res);
-
-    Chain msg;
-    _pAH->getMsg(msg);
-    if ( _rawMode == false )
-	cout << msg << endl;
-}
-
-void CegoAdmAction::checkTableSetAction()
-{
-    Chain tableSet;
-    Chain* pS = getTokenList().First();
-    if ( pS )
-    {
-	tableSet = *pS;
-    }
-    
-    CegoAdminHandler::ResultType res;
-    res = _pAH->medCheckTableSet(tableSet);
-    handleMedResult(res);
-
-    CegoTableObject oe;
-    ListT<ListT<CegoFieldValue> > info;
-    _pAH->getTableSetCheck(oe, info);
-    CegoOutput output(oe.getSchema());
-    output.setRawMode(_rawMode);
-    output.tabOut(info);
-}
 
 void CegoAdmAction::verifyTableSetAction()
 {
@@ -2078,7 +1875,7 @@ void CegoAdmAction::verifyTableSetAction()
     }
 
     CegoAdminHandler::ResultType res;
-    res = _pAH->medVerifyTableSet(tableSet);
+    res = _pAH->reqVerifyTableSet(tableSet);
     
     if ( res == CegoAdminHandler::ADM_ERROR )
     {
@@ -2135,7 +1932,7 @@ void CegoAdmAction::correctTableSetAction()
     }
 
     CegoAdminHandler::ResultType res;
-    res = _pAH->medCorrectTableSet(tableSet);
+    res = _pAH->reqCorrectTableSet(tableSet);
     if ( res == CegoAdminHandler::ADM_ERROR )
     {
 	Chain msg;
@@ -2181,78 +1978,6 @@ void CegoAdmAction::correctTableSetAction()
     }
 }
 
-void CegoAdmAction::getDbSpecAction() 
-{
-    CegoAdminHandler::ResultType res;   
-    Chain dbSpec;
-    res = _pAH->reqGetDbSpec(dbSpec);
-    if ( res == CegoAdminHandler::ADM_OK )
-    {
-	Chain msg;
-	_pAH->getMsg(msg);
-	cout << msg << endl;
-	cout << "DBSPEC=" << dbSpec << endl;
-    }
-    else if ( res == CegoAdminHandler::ADM_ERROR )
-    {
-	Chain msg;
-	_pAH->getMsg(msg);
-	throw Exception(EXLOC, msg);
-    }
-}
-
-void CegoAdmAction::listNodeAction() 
-{
-    CegoAdminHandler::ResultType res;   
-    res = _pAH->reqGetNodeList();
-
-    if ( res == CegoAdminHandler::ADM_OK )
-    {
-	CegoTableObject oe;
-	ListT<ListT<CegoFieldValue> > info;
-
-	_pAH->getNodeInfo(oe, info);
-
-	CegoOutput output(oe.getSchema());
-	output.setRawMode(_rawMode);
-	output.tabOut(info);
-
-	if ( _rawMode == false )
-	{
-	    Chain msg;
-	    _pAH->getMsg(msg);
-	    cout << msg << endl;
-	}
-    }
-    else if ( res == CegoAdminHandler::ADM_ERROR )
-    {
-	Chain msg;
-	_pAH->getMsg(msg);
-	throw Exception(EXLOC, msg);
-    }
-}
-
-void CegoAdmAction::getDbInfoAction() 
-{
-    CegoAdminHandler::ResultType res;   
-    res = _pAH->reqGetDbInfo();
-
-    if ( res == CegoAdminHandler::ADM_OK )
-    {
-	if ( _rawMode == false )
-	{
-	    Chain msg;
-	    _pAH->getMsg(msg);
-	    cout << msg << endl;
-	}
-    }
-    else if ( res == CegoAdminHandler::ADM_ERROR )
-    {
-	Chain msg;
-	_pAH->getMsg(msg);
-	throw Exception(EXLOC, msg);
-    }
-}
 
 void CegoAdmAction::tableSetInfoAction() 
 {
@@ -2264,9 +1989,9 @@ void CegoAdmAction::tableSetInfoAction()
     }
 
     CegoAdminHandler::ResultType res;
-    res = _pAH->medGetDetailedTableSetInfo(tableSet);
+    res = _pAH->reqGetDetailedTSInfo(tableSet);
     
-    handleMedResult(res);    
+    handleResult(res);    
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -2292,9 +2017,9 @@ void CegoAdmAction::dataFileInfoAction()
     }
 
     CegoAdminHandler::ResultType res;   
-    res = _pAH->medGetDetailedTableSetInfo(tableSet);
+    res = _pAH->reqGetDetailedTSInfo(tableSet);
 
-    handleMedResult(res);
+    handleResult(res);
     
     CegoTableObject oe;
     ListT<ListT<CegoFieldValue> > info;
@@ -2321,9 +2046,9 @@ void CegoAdmAction::archLogInfoAction()
     }
 
     CegoAdminHandler::ResultType res;
-    res = _pAH->medGetArchLogInfo(tableSet);
+    res = _pAH->reqGetArchLogInfo(tableSet);
     
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -2350,9 +2075,9 @@ void CegoAdmAction::logInfoAction()
     }
 
     CegoAdminHandler::ResultType res;
-    res = _pAH->medGetDetailedTableSetInfo(tableSet);
+    res = _pAH->reqGetDetailedTSInfo(tableSet);
 
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -2379,8 +2104,8 @@ void CegoAdmAction::objInfoAction()
     }
 
     CegoAdminHandler::ResultType res;
-    res = _pAH->medGetObjectInfo(tableSet);
-    handleMedResult(res);
+    res = _pAH->reqGetObjectInfo(tableSet);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -2407,8 +2132,8 @@ void CegoAdmAction::transactionInfoAction()
     }
 
     CegoAdminHandler::ResultType res;
-    res = _pAH->medGetTransactionInfo(tableSet);
-    handleMedResult(res);
+    res = _pAH->reqGetTransactionInfo(tableSet);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -2425,75 +2150,6 @@ void CegoAdmAction::transactionInfoAction()
 	cout << msg << endl;
 }
 
-void CegoAdmAction::setTableSetNodeAction() 
-{
-    Chain tableSet;
-    Chain primary;
-    Chain secondary;
-    Chain mediator;
-
-    Chain* pS = getTokenList().First();
-    if ( pS )
-    {
-	mediator = *pS;
-    }
-    pS = getTokenList().Next();
-    if ( pS )
-    {
-	 secondary = *pS;
-    }
-    pS = getTokenList().Next();
-    if ( pS )
-    {
-	 primary = *pS;
-    }
-    pS = getTokenList().Next();
-    if ( pS )
-    {
-	 tableSet = *pS;
-    }
-
-    CegoAdminHandler::ResultType res;
-    res = _pAH->reqSetTableSetNode(tableSet, primary, secondary, mediator);
-    if ( res == CegoAdminHandler::ADM_OK )
-    {
-	if ( _rawMode == false )
-	{
-	    Chain msg;
-	    _pAH->getMsg(msg);
-	    cout << msg << endl;
-	}
-    }
-    else if ( res == CegoAdminHandler::ADM_ERROR )
-    {
-	Chain msg;
-	_pAH->getMsg(msg);
-	throw Exception(EXLOC, msg);
-    }
-}
-
-void CegoAdmAction::copyFileAction() 
-{
-    CegoAdminHandler::ResultType res;   
-    Chain fileName(_stringBuf);
-    res = _pAH->reqCopyFile(fileName);
-    if ( res == CegoAdminHandler::ADM_OK )
-    {
-	if ( _rawMode == false )
-	{
-	    Chain msg;
-	    _pAH->getMsg(msg);
-	    cout << msg << endl;
-	}
-    }
-    else if ( res == CegoAdminHandler::ADM_ERROR )
-    {
-	Chain msg;
-	_pAH->getMsg(msg);
-	throw Exception(EXLOC, msg);
-    }
-}
-
 void CegoAdmAction::exportTableAction()
 {
     Chain exportFile(_stringBuf);
@@ -2519,7 +2175,7 @@ void CegoAdmAction::exportTableAction()
     
     res = _pAH->reqExportTable(tableSet, tableName, exportFile, _xportMode);
     
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -2545,7 +2201,7 @@ void CegoAdmAction::exportTableSetAction()
         
     CegoAdminHandler::ResultType res;
     res = _pAH->reqExportTableSet(tableSet, false, exportFile, _xportMode);
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -2573,7 +2229,7 @@ void CegoAdmAction::exportTableSetStructureAction()
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqExportTableSet(tableSet, true, exportFile, _xportMode);
-    handleMedResult(res);
+    handleResult(res);
 
     _xportMode = XML_XML_VALUE;
 
@@ -2608,7 +2264,7 @@ void CegoAdmAction::importTableAction()
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqImportTable(tableSet, tableName, importFile, _xportMode);	
-    handleMedResult(res);
+    handleResult(res);
 
     _xportMode = XML_XML_VALUE;
 
@@ -2635,7 +2291,7 @@ void CegoAdmAction::importTableSetAction()
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqImportTableSet(tableSet, false, importFile, _xportMode);
-    handleMedResult(res);
+    handleResult(res);
 
     _xportMode = XML_XML_VALUE;
 
@@ -2663,7 +2319,7 @@ void CegoAdmAction::importTableSetStructureAction()
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqImportTableSet(tableSet, true, importFile, _xportMode);
-    handleMedResult(res);
+    handleResult(res);
 
     _xportMode = XML_XML_VALUE;
 
@@ -2718,9 +2374,9 @@ void CegoAdmAction::addDataFileAction()
     }
 
     CegoAdminHandler::ResultType res;    
-    res = _pAH->medAddDataFile(tableSet, fileType, dataFile, numPages);
+    res = _pAH->reqAddDataFile(tableSet, fileType, dataFile, numPages);
 
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -2733,7 +2389,7 @@ void CegoAdmAction::listUserAction()
     CegoAdminHandler::ResultType res;
     res = _pAH->reqShowUser();
 
-    handleMedResult(res);
+    handleResult(res);
 
     CegoTableObject oe;
     ListT<ListT<CegoFieldValue> > info;
@@ -2762,7 +2418,7 @@ void CegoAdmAction::addUserAction()
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqAddUser(user, password);
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -2784,7 +2440,7 @@ void CegoAdmAction::removeUserAction()
     CegoAdminHandler::ResultType res;
     
     res = _pAH->reqRemoveUser(user);
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -2809,7 +2465,7 @@ void CegoAdmAction::changePwdAction()
     CegoAdminHandler::ResultType res;   
     res = _pAH->reqChangePwd(user, password);
     
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -2837,7 +2493,7 @@ void CegoAdmAction::assignRoleAction()
     CegoAdminHandler::ResultType res;   
     res = _pAH->reqAssignRole(user, role);
 
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -2865,7 +2521,7 @@ void CegoAdmAction::removeRoleAction()
     CegoAdminHandler::ResultType res;   
     res = _pAH->reqRemoveRole(user, role);
 
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -2878,7 +2534,7 @@ void CegoAdmAction::listRoleAction()
     CegoAdminHandler::ResultType res;   
     res = _pAH->reqListRole();
     
-    handleMedResult(res);
+    handleResult(res);
 
     CegoTableObject oe;
     ListT<ListT<CegoFieldValue> > info;
@@ -2903,7 +2559,7 @@ void CegoAdmAction::showRoleAction()
     CegoAdminHandler::ResultType res;   
     res = _pAH->reqShowRole(role);
     
-    handleMedResult(res);
+    handleResult(res);
 
     CegoTableObject oe;
     ListT<ListT<CegoFieldValue> > info;
@@ -2928,7 +2584,7 @@ void CegoAdmAction::createRoleAction()
     CegoAdminHandler::ResultType res;   
     res = _pAH->reqCreateRole(role);
     
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -2949,7 +2605,7 @@ void CegoAdmAction::dropRoleAction()
     CegoAdminHandler::ResultType res;
     res = _pAH->reqDropRole(role);
 
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -2979,7 +2635,7 @@ void CegoAdmAction::setPermAction()
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSetPermission(role, permid, _tsPerm, _filterPerm, _rightPerm);
     
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -3030,7 +2686,7 @@ void CegoAdmAction::removePermAction()
     CegoAdminHandler::ResultType res;
     res = _pAH->reqRemovePermission(role, permid);
     
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -3051,7 +2707,7 @@ void CegoAdmAction::traceOnAction()
     CegoAdminHandler::ResultType res;   
     res = _pAH->reqUserTrace(user, true);
     
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -3072,7 +2728,7 @@ void CegoAdmAction::traceOffAction()
     CegoAdminHandler::ResultType res;   
     res = _pAH->reqUserTrace(user, false);
     
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -3101,9 +2757,9 @@ void CegoAdmAction::addArchLogAction()
     }
        
     CegoAdminHandler::ResultType res;    
-    res = _pAH->medAddArchLog(tableSet, archId, archPath);
+    res = _pAH->reqAddArchLog(tableSet, archId, archPath);
     
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -3129,9 +2785,9 @@ void CegoAdmAction::removeArchLogAction()
     }
         
     CegoAdminHandler::ResultType res;   
-    res = _pAH->medRemoveArchLog(tableSet, archId);
+    res = _pAH->reqRemoveArchLog(tableSet, archId);
     
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -3150,9 +2806,9 @@ void CegoAdmAction::enableArchLogAction()
     }
         
     CegoAdminHandler::ResultType res;   
-    res = _pAH->medEnableArchLog(tableSet);
+    res = _pAH->reqEnableArchLog(tableSet);
     
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -3172,8 +2828,8 @@ void CegoAdmAction::disableArchLogAction()
         
     CegoAdminHandler::ResultType res;
     
-    res = _pAH->medDisableArchLog(tableSet);
-    handleMedResult(res);
+    res = _pAH->reqDisableArchLog(tableSet);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -3192,9 +2848,9 @@ void CegoAdmAction::enableAppendModeAction()
     }
         
     CegoAdminHandler::ResultType res;   
-    res = _pAH->medEnableAppendMode(tableSet);
+    res = _pAH->reqEnableAppendMode(tableSet);
     
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -3213,9 +2869,9 @@ void CegoAdmAction::disableAppendModeAction()
     }
         
     CegoAdminHandler::ResultType res;   
-    res = _pAH->medDisableAppendMode(tableSet);
+    res = _pAH->reqDisableAppendMode(tableSet);
     
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -3234,9 +2890,9 @@ void CegoAdmAction::enableAutoCorrectAction()
     }
         
     CegoAdminHandler::ResultType res;   
-    res = _pAH->medEnableAutoCorrect(tableSet);
+    res = _pAH->reqEnableAutoCorrect(tableSet);
     
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -3255,9 +2911,9 @@ void CegoAdmAction::disableAutoCorrectAction()
     }
         
     CegoAdminHandler::ResultType res;   
-    res = _pAH->medDisableAutoCorrect(tableSet);
+    res = _pAH->reqDisableAutoCorrect(tableSet);
     
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -3278,7 +2934,7 @@ void CegoAdmAction::enableTableCacheAction()
     CegoAdminHandler::ResultType res;   
     res = _pAH->reqEnableTableCache(tableSet);
     
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -3299,7 +2955,7 @@ void CegoAdmAction::disableTableCacheAction()
     CegoAdminHandler::ResultType res;   
     res = _pAH->reqDisableTableCache(tableSet);
     
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -3320,7 +2976,7 @@ void CegoAdmAction::enableQueryCacheAction()
     CegoAdminHandler::ResultType res;   
     res = _pAH->reqEnableQueryCache(tableSet);
     
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -3341,7 +2997,7 @@ void CegoAdmAction::disableQueryCacheAction()
     CegoAdminHandler::ResultType res;   
     res = _pAH->reqDisableQueryCache(tableSet);
     
-    handleMedResult(res);
+    handleResult(res);
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -3403,16 +3059,6 @@ void CegoAdmAction::storeSortAreaAttr()
     }
 }
 
-void CegoAdmAction::storePrimaryAttr()
-{
-    _primary = Chain(_stringBuf);   
-}
-
-void CegoAdmAction::storeSecondaryAttr()
-{
-    _secondary = Chain(_stringBuf);   
-}
-
 void CegoAdmAction::storeTSRootAttr()
 {
     _tsRoot = Chain(_stringBuf);
@@ -3516,7 +3162,7 @@ void CegoAdmAction::dumpUIndex()
     }    
 }
 
-void CegoAdmAction::handleMedResult(CegoAdminHandler::ResultType res)
+void CegoAdmAction::handleResult(CegoAdminHandler::ResultType res)
 {
     if ( res == CegoAdminHandler::ADM_ERROR )
     {
