@@ -151,7 +151,7 @@ void CegoBTreeManager::commit(CegoDataPointer& sysEntry)
     }
 
     char *p;
-    int len;
+    unsigned len;
     CegoBufferPage rbp;
     _pObjMng->claimDataPtrUnlocked(_tabSetId, CegoBufferPool::NOSYNC, sysEntry, p, len, rbp);
     _pBTO->encode(p);
@@ -693,7 +693,7 @@ void CegoBTreeManager::deleteBTree(const CegoDataPointer& sysEntry,
 		{		    
 		    _pBTO->decreaseRelevance();
 		    char *p;
-		    int len;
+		    unsigned len;
 		    CegoBufferPage bp;
 		    _pObjMng->claimDataPtrUnlocked(_tabSetId, CegoBufferPool::NOSYNC, sysEntry, p, len, bp);
 		    _pBTO->encode(p);
@@ -746,7 +746,7 @@ CegoBufferPage* CegoBTreeManager::allocPage(CegoBufferPage::PageType type)
 		
 	PageIdType pageId;	
 	unsigned* fbm;
-	int fbmSize=0;
+	unsigned fbmSize=0;
 	CegoFileHandler::FileType ft = CegoFileHandler::DATAFILE;
 	bool doAppend = true;
 
@@ -806,7 +806,7 @@ bool CegoBTreeManager::verifyNode(PageIdType pageId)
     
     _pDBMng->bufferFix(bp, _tabSetId, pageId, CegoBufferPool::NOSYNC, _pObjMng->getLockHandler());
 
-    int numError = 0;
+    unsigned numError = 0;
     
     CegoBTreeNode traceNode;
     traceNode.setPtr(bp.getChunkEntry(), bp.getChunkLen());
@@ -855,7 +855,7 @@ void CegoBTreeManager::dumpBTree()
     dumpNode(0, pageId);
 }
 
-void CegoBTreeManager::dumpNode(int level, PageIdType pageId)
+void CegoBTreeManager::dumpNode(unsigned level, PageIdType pageId)
 {
     CegoBufferPage bp;
     
@@ -893,14 +893,14 @@ void CegoBTreeManager::dumpNode(int level, PageIdType pageId)
     _pDBMng->bufferUnfix(bp, false, _pObjMng->getLockHandler());
 }
 
-int CegoBTreeManager::freeBTree()
+unsigned CegoBTreeManager::freeBTree()
 {
     PageIdType firstLeafPageId = 0;
     bool isFirst = true;
 
     PageIdType pageId = _pBTO->getDataPageId();
 
-    int pageCount;
+    unsigned pageCount;
 
     if ( pageId == 0 )
     {
@@ -915,9 +915,9 @@ int CegoBTreeManager::freeBTree()
     return pageCount;
 }
 
-int CegoBTreeManager::freeNodePages(PageIdType pageId, PageIdType& firstLeafPageId, bool& isFirst)
+unsigned CegoBTreeManager::freeNodePages(PageIdType pageId, PageIdType& firstLeafPageId, bool& isFirst)
 {
-    int pageCount = 0;
+    unsigned pageCount = 0;
 
     CegoBufferPage bp;    
     _pDBMng->bufferFix(bp, _tabSetId, pageId, CegoBufferPool::NOSYNC, _pObjMng->getLockHandler());
@@ -960,9 +960,9 @@ int CegoBTreeManager::freeNodePages(PageIdType pageId, PageIdType& firstLeafPage
     return pageCount;
 }
 
-int CegoBTreeManager::freeLeafPages(PageIdType pageId)
+unsigned CegoBTreeManager::freeLeafPages(PageIdType pageId)
 {
-    int pageCount = 0;
+    unsigned pageCount = 0;
 
     while ( pageId )
     {
@@ -976,14 +976,14 @@ int CegoBTreeManager::freeLeafPages(PageIdType pageId)
     return pageCount;
 }
 
-int CegoBTreeManager::traceBTree()
+unsigned CegoBTreeManager::traceBTree()
 {
     PageIdType firstLeafPageId = 0;
     bool isFirst = true;
 
     PageIdType pageId = _pBTO->getDataPageId();
 
-    int pageCount;
+    unsigned pageCount;
 
     if ( pageId == 0 )
     {
@@ -997,9 +997,9 @@ int CegoBTreeManager::traceBTree()
     return pageCount;
 }
 
-int CegoBTreeManager::traceNodePages(PageIdType pageId, PageIdType& firstLeafPageId, bool& isFirst)
+unsigned CegoBTreeManager::traceNodePages(PageIdType pageId, PageIdType& firstLeafPageId, bool& isFirst)
 {
-    int pageCount = 0;
+    unsigned pageCount = 0;
 
     CegoBufferPage bp;    
     _pDBMng->bufferFix(bp, _tabSetId, pageId, CegoBufferPool::NOSYNC, _pObjMng->getLockHandler());
@@ -1045,9 +1045,9 @@ int CegoBTreeManager::traceNodePages(PageIdType pageId, PageIdType& firstLeafPag
     return pageCount;
 }
 
-int CegoBTreeManager::traceLeafPages(PageIdType pageId)
+unsigned CegoBTreeManager::traceLeafPages(PageIdType pageId)
 {
-    int pageCount = 0;
+    unsigned pageCount = 0;
 
     while ( pageId )
     {
@@ -1064,14 +1064,14 @@ int CegoBTreeManager::traceLeafPages(PageIdType pageId)
     return pageCount;
 }
 
-int CegoBTreeManager::getNumPages()
+unsigned CegoBTreeManager::getNumPages()
 {    
     PageIdType firstLeafPageId = 0;
     bool isFirst = true;
 
     PageIdType pageId = _pBTO->getDataPageId();
     
-    int pageCount = 0;
+    unsigned pageCount = 0;
 
     if ( pageId == 0 )
     {
@@ -1079,16 +1079,16 @@ int CegoBTreeManager::getNumPages()
     }
     else
     {
-	int numNodePage = countNodePages(pageId, firstLeafPageId, isFirst);
-	int numLeafPage = countLeafPages(firstLeafPageId);
+	unsigned numNodePage = countNodePages(pageId, firstLeafPageId, isFirst);
+	unsigned numLeafPage = countLeafPages(firstLeafPageId);
 	pageCount = numNodePage + numLeafPage;
     }
     return pageCount;
 }
 
-int CegoBTreeManager::countNodePages(PageIdType pageId, PageIdType& firstLeafPageId, bool& isFirst)
+unsigned CegoBTreeManager::countNodePages(PageIdType pageId, PageIdType& firstLeafPageId, bool& isFirst)
 {
-    int pageCount = 0;
+    unsigned pageCount = 0;
 
     CegoBufferPage bp;
    
@@ -1126,9 +1126,9 @@ int CegoBTreeManager::countNodePages(PageIdType pageId, PageIdType& firstLeafPag
     return pageCount;
 }
 
-int CegoBTreeManager::countLeafPages(PageIdType pageId)
+unsigned CegoBTreeManager::countLeafPages(PageIdType pageId)
 {
-    int pageCount = 0;
+    unsigned pageCount = 0;
 
     while ( pageId )
     {	
