@@ -8,7 +8,7 @@
 //                                                         
 // Design and Implementation by Bjoern Lemke               
 //     
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
@@ -23,13 +23,15 @@
 // LFC INCLUDES
 #include <lfcbase/Chain.h>
 
+#include "CegoDefs.h"
+
 class CegoBlob {
     
 public:
     
     CegoBlob();  
-    CegoBlob(int fileId, int pageId);
-    CegoBlob(int fileId, int pageId, unsigned char *blobBuf, unsigned long long blobSize);  
+    CegoBlob(PageIdType pageId);
+    CegoBlob(PageIdType pageId, unsigned char *blobBuf, unsigned long long blobSize);  
     ~CegoBlob();
 
     void readBlob(const Chain& fileName);
@@ -39,6 +41,8 @@ public:
     unsigned char* getBufPtr();
 
     void allocate(unsigned long long size);
+    void release();
+    
     void reset();
 
     bool nextChunk(unsigned long long chunkSize);
@@ -46,28 +50,23 @@ public:
     unsigned char* getChunkPtr();
     unsigned long long getChunkSize();
 
-    void setFileId(int fileId);
-    int getFileId() const;
-
-    void setPageId(int pageId);
-    int getPageId() const;
+    void setPageId(PageIdType pageId);
+    PageIdType getPageId() const;
 
     CegoBlob& operator = ( const CegoBlob& b);
     bool operator == ( const CegoBlob& b);
-
+    
     Chain toChain() const;
     friend ostream& operator << (ostream& s, const CegoBlob& b);
     
 private:
 
-    int _fileId;
-    int _pageId;
+    PageIdType _pageId;
 
     unsigned long long _size;
     unsigned char *_buf;
 
     unsigned long long _chunkSize;
     unsigned char *_chunkPtr;
-
 };
 #endif
