@@ -29,7 +29,7 @@
 #include <string.h>
 #include <stdlib.h>
 
-#define ALLOCDELTA sizeof(int)
+#define ALLOCDELTA sizeof(unsigned)
 
 // to ensure memory alignment, pagehead size is need to be calculated in the
 // following way ( at least required for SPARC ) 
@@ -58,7 +58,7 @@ CegoBufferPage::CegoBufferPage(const CegoBufferPage &bp)
     _isFixed = bp._isFixed;    
 }
 
-CegoBufferPage::CegoBufferPage(void* pagePtr, int pageSize)
+CegoBufferPage::CegoBufferPage(void* pagePtr, unsigned pageSize)
 {
     _pageSize = pageSize;       
     _pagePtr = (char*)pagePtr;
@@ -91,10 +91,10 @@ void CegoBufferPage::initPage(CegoBufferPage::PageType t)
 
     if ( t == TABLE || t == TUPLE )
     {
-	int* ePtr = (int*)((long long)_pagePtr + PAGEHEAD);
+	unsigned* ePtr = (unsigned*)((long long)_pagePtr + PAGEHEAD);
 	*ePtr = 0;
 	
-	int* freePtr = (int*)((long long)_pagePtr + (long)_pageSize);
+	unsigned* freePtr = (unsigned*)((long long)_pagePtr + (long)_pageSize);
 	freePtr--;
 	*freePtr=0;
     }
@@ -110,7 +110,7 @@ void CegoBufferPage::setPageHead(PageHead* ptr)
     _pageHead = ptr;
 }
 
-void CegoBufferPage::setPageSize(int pageSize)
+void CegoBufferPage::setPageSize(unsigned pageSize)
 {
     _pageSize = pageSize;
 }
@@ -135,9 +135,9 @@ PageIdType& CegoBufferPage::getNextPageId() const
     return _pageHead->nextPageId;
 }
 
-int CegoBufferPage::getNumEntries()
+unsigned CegoBufferPage::getNumEntries()
 {
-    int numEntries = 0;
+    unsigned numEntries = 0;
     if ( getFirstEntry() )
     {
 	numEntries++;
@@ -157,22 +157,22 @@ CegoBufferPage::PageType& CegoBufferPage::getType() const
     return _pageHead->pageType;
 }
 
-void* CegoBufferPage::newEntry(int size)
+void* CegoBufferPage::newEntry(unsigned size)
 {   
     if ( size % BUPMNG_ALIGNMENT )
 	size = ( size / BUPMNG_ALIGNMENT + 1) * BUPMNG_ALIGNMENT;
     
-    int* ePtr;
+    unsigned* ePtr;
     
-    int* freePtr = (int*)((long long)_pagePtr + (long)_pageSize);
+    unsigned* freePtr = (unsigned*)((long long)_pagePtr + (long)_pageSize);
     freePtr--;
     
     while (*freePtr != 0 )
     {
-	ePtr = (int*)((long long)_pagePtr + *freePtr);
-	if (*ePtr >=  size && *ePtr <= (int)(size + ALLOCDELTA))
+	ePtr = (unsigned*)((long long)_pagePtr + *freePtr);
+	if (*ePtr >=  size && *ePtr <= (unsigned)(size + ALLOCDELTA))
 	{
-	    int* sPtr = freePtr;
+	    unsigned* sPtr = freePtr;
 	    
 	    while (*(sPtr-1) != 0)
 	    {
@@ -184,17 +184,17 @@ void* CegoBufferPage::newEntry(int size)
 	    ePtr++;
 	    return ePtr;
 	}
-	else if (*ePtr > (int)(size + ALLOCDELTA))
+	else if (*ePtr > (unsigned)(size + ALLOCDELTA))
 	{
-	    int osize = *ePtr;
+	    unsigned osize = *ePtr;
 	  	   
 	    *ePtr = size;
 		
 	    char* tPtr = (char*)ePtr;
-	    tPtr += size + sizeof(int);
+	    tPtr += size + sizeof(unsigned);
 		
-	    int* sPtr = (int*)tPtr;
-	    *sPtr= osize - size - sizeof(int);
+	    unsigned* sPtr = (unsigned*)tPtr;
+	    *sPtr= osize - size - sizeof(unsigned);
 	    
 	    *freePtr = (long long)sPtr - (long long)_pagePtr;
 	    
@@ -208,13 +208,13 @@ void* CegoBufferPage::newEntry(int size)
     // no appropriate entry found in freelist,
     // allocating new space
     
-    int* fPtr = (int*)((long long)_pagePtr + PAGEHEAD);
+    unsigned* fPtr = (unsigned*)((long long)_pagePtr + PAGEHEAD);
     
     // cout << "fptr is " << (int)fPtr << endl;
 
-    while (*(int*)fPtr != 0 )
+    while (*(unsigned*)fPtr != 0 )
     {	
-	fPtr = (int*)((long long)fPtr + *fPtr + sizeof(int));
+	fPtr = (unsigned*)((long long)fPtr + *fPtr + sizeof(unsigned));
     }
     
     // check if enough memory in page
@@ -225,10 +225,10 @@ void* CegoBufferPage::newEntry(int size)
 	return 0;
     }
     
-    *(int*)fPtr = size;
+    *(unsigned*)fPtr = size;
     char *sPtr = (char*)fPtr;
-    sPtr = sPtr + size + sizeof(int);
-    int* nPtr = (int*)sPtr;
+    sPtr = sPtr + size + sizeof(unsigned);
+    unsigned* nPtr = (unsigned*)sPtr;
     *nPtr = 0;
 
     fPtr++;
@@ -238,32 +238,33 @@ void* CegoBufferPage::newEntry(int size)
 
 void CegoBufferPage::freeEntry(void* p)
 {
-    int* freePtr = (int*)((long long)_pagePtr + (long)_pageSize);
+    unsigned* freePtr = (unsigned*)((long long)_pagePtr + (long)_pageSize);
     freePtr--;
     
-    int* setptr[2];
+    unsigned* setptr[2];
 
-    setptr[0]=0;    
+    setptr[0]=0;
     setptr[1]=0;
     
-    int i = 0;
-    int n = 0;
-    int count=0;
+    unsigned i = 0;
+    unsigned n = 0;
+    unsigned count=0;
     
-    while ( *freePtr && count < (int)(( _pageSize * BUPMNG_MINFREERATIO) / ( 100 * sizeof(int))))
+    while ( *freePtr && count < (unsigned)(( _pageSize * BUPMNG_MINFREERATIO) / ( 100 * sizeof(unsigned))))
     {
 	// cout << "*FreePtr=" << *freePtr << endl;
 	// cout << "p pos " << ((int)p - (int)_pagePtr) << endl;
 	// cout << "p size " << *((int*)p -1) << endl;
 	// cout << "size of freePtr " << *(int*)(*freePtr + (int)_pagePtr) << endl;
 	
-	if ( *freePtr == ((long long)p - (long long)_pagePtr) + *((int*)p - 1))
+	if ( *freePtr == ((long long)p - (long long)_pagePtr) + *((unsigned*)p - 1))
 	{
 	    // cout << "right free neighbour detected" << endl;
 	    setptr[i]=freePtr;
 	    i++;
 	}
-	else if (*freePtr + sizeof(int) + *(int*)(*freePtr + (long long)_pagePtr)  == ((long long)p - (long long)_pagePtr) - sizeof(int))
+	else if (*freePtr + sizeof(unsigned) + *(unsigned*)(*freePtr + (long long)_pagePtr)
+		 == ((long long)p - (long long)_pagePtr) - sizeof(unsigned))
 	{
 	    // cout << "left free neighbour detected" << endl;   
 	    setptr[i]=freePtr;
@@ -274,7 +275,7 @@ void CegoBufferPage::freeEntry(void* p)
 	count++;
     }
 
-    if (count == (int)(( _pageSize * BUPMNG_MINFREERATIO ) / ( 100 * sizeof(int))))
+    if (count == (unsigned)(( _pageSize * BUPMNG_MINFREERATIO ) / ( 100 * sizeof(unsigned))))
     {
 	throw Exception(EXLOC, "Minfree exceeded");
     }
@@ -282,47 +283,49 @@ void CegoBufferPage::freeEntry(void* p)
     {
     case 0:
     {
-	*freePtr = (long long)p - (long long)_pagePtr - sizeof(int);
+	*freePtr = (long long)p - (long long)_pagePtr - sizeof(unsigned);
 	freePtr--;
 	*freePtr = 0;
 	break;
     }
     case 1:
     {
-	int newsize = *((int*)p -1) + *(int*)( *setptr[0] + (long long)_pagePtr) + sizeof(int);
+	unsigned newsize = *((unsigned*)p-1) + *(unsigned*)( *setptr[0] + (long long)_pagePtr) + sizeof(unsigned);
 	
 	// cout << "Setup newsize with " << newsize << endl;
 	
 	if (*setptr[0] > (long long)p - (long long)_pagePtr)
 	{	    
-	    *setptr[0] = (long long)p - (long long)_pagePtr - sizeof(int);
-	    *((int*)p - 1) = newsize;
+	    *setptr[0] = (long long)p - (long long)_pagePtr - sizeof(unsigned);
+	    *((unsigned*)p-1) = newsize;
 	}
 	else if (*setptr[0] < (long long)p - (long long)_pagePtr)
 	{   
-	    *(int*)( *setptr[0] + (long long)_pagePtr) = newsize;
+	    *(unsigned*)( *setptr[0] + (long long)_pagePtr) = newsize;
 	}	
 	break;
     }
     case 2:
     {	
-	int newsize = *((int*)p -1) + *(int*)( *setptr[0] + (long long)_pagePtr) + *(int*)( *setptr[1] + (long long)_pagePtr) + 2 * sizeof(int);
+	unsigned newsize = *((unsigned*)p -1)
+	    + *(unsigned*)( *setptr[0]+ (long long)_pagePtr)
+	    + *(unsigned*)( *setptr[1] + (long long)_pagePtr) + 2 * sizeof(unsigned);
 	
 	// cout << "Setup newsize with " << newsize << endl;
 
-	int* newptr = setptr[n];
+	unsigned* newptr = setptr[n];
 	
 	if (*setptr[0] > (long long)p)
 	{
 	    *setptr[0] = *newptr;
-	    *(int*)( *setptr[0] + (long long)_pagePtr) = newsize;
+	    *(unsigned*)( *setptr[0] + (long long)_pagePtr) = newsize;
 	    freePtr++;
 	    *setptr[1] = *freePtr;
 	} 
 	else
 	{
 	    *setptr[1] = *newptr;
-	    *(int*)( *setptr[1] + (long long)_pagePtr) = newsize;
+	    *(unsigned*)( *setptr[1] + (long long)_pagePtr) = newsize;
 	    freePtr++;
 	    *setptr[0] = *freePtr;
 	}
@@ -351,10 +354,10 @@ void* CegoBufferPage::getNextEntry()
 
     // cout << "Next entry .." << endl;
     
-    while ( *(int*)_ePtr != 0 )
+    while ( *(unsigned*)_ePtr != 0 )
     {
 	// checking free list
-	int* freePtr = (int*)((long long)_pagePtr + (long long)_pageSize);
+	unsigned* freePtr = (unsigned*)((long long)_pagePtr + (long long)_pageSize);
 
 	freePtr--;
 		
@@ -375,15 +378,15 @@ void* CegoBufferPage::getNextEntry()
 	if ( isFreeEntry )
 	{
 	    // skipping free entry
-	    _entryPos = _entryPos + *((int*)_ePtr) + sizeof(int);
-	    _ePtr = _ePtr + *((int*)_ePtr) + sizeof(int);
+	    _entryPos = _entryPos + *((unsigned*)_ePtr) + sizeof(unsigned);
+	    _ePtr = _ePtr + *((unsigned*)_ePtr) + sizeof(unsigned);
 	}
 	else
 	{	  
-	    _entryLen = *(int*)_ePtr; 
-	    char* rPtr = _ePtr + sizeof(int);	    
-	    _entryPos = _ePtr - _pagePtr + sizeof(int);	    
-	    _ePtr = _ePtr + *((int*)_ePtr) + sizeof(int);
+	    _entryLen = *(unsigned*)_ePtr; 
+	    char* rPtr = _ePtr + sizeof(unsigned);	    
+	    _entryPos = _ePtr - _pagePtr + sizeof(unsigned);	    
+	    _ePtr = _ePtr + *((unsigned*)_ePtr) + sizeof(unsigned);
 	    return rPtr;
     	}
     }
@@ -395,22 +398,22 @@ char* CegoBufferPage::getChunkEntry() const
     return (char*)((long long)_pagePtr + PAGEHEAD);
 }
 
-int CegoBufferPage::getPageSize() const
+unsigned CegoBufferPage::getPageSize() const
 {
     return _pageSize;    
 }
 
-int CegoBufferPage::getChunkLen() const
+unsigned CegoBufferPage::getChunkLen() const
 {
     return _pageSize - PAGEHEAD;    
 }
 
-int CegoBufferPage::getEntryLen() const
+unsigned CegoBufferPage::getEntryLen() const
 {
     return _entryLen;
 }
 
-int CegoBufferPage::getEntryPos() const
+unsigned CegoBufferPage::getEntryPos() const
 {
     return _entryPos;
 }
@@ -428,21 +431,21 @@ void CegoBufferPage::printPage()
     cout << "PageSize: " << _pageSize << endl;
     cout << "PagePtr: " << (unsigned long long)_pagePtr << endl;
 
-    int* e = (int*)getFirstEntry();
-    int i=1;
+    unsigned* e = (unsigned*)getFirstEntry();
+    unsigned i=1;
     if (e)
     {
 	e--;
 	cout << "Entry " << i << " Pos=" << (long long)e - (long long)_pagePtr << " Size=" << *e << endl;
 	i++;
-	while ( ( e = (int*)getNextEntry()) != 0  )
+	while ( ( e = (unsigned*)getNextEntry()) != 0  )
 	{
 	    e--;
 	    cout << "Entry " << i << " Pos=" << (long long)e - (long long)_pagePtr << " Size=" << *e << endl;
 	    i++;
 	}
     }
-    int* freePtr = (int*)((long long)_pagePtr + (long)_pageSize);
+    unsigned* freePtr = (unsigned*)((long long)_pagePtr + (long)_pageSize);
     freePtr--;
     
     cout << "---------------------------" << endl;
@@ -450,7 +453,7 @@ void CegoBufferPage::printPage()
     i=1;
     while ( *freePtr )
     {
-	cout << "Free Entry " << i << " Pos=" << *freePtr << " Size=" << *(int*)(*freePtr + (long long)_pagePtr)<< endl;
+	cout << "Free Entry " << i << " Pos=" << *freePtr << " Size=" << *(unsigned*)(*freePtr + (long long)_pagePtr)<< endl;
 	i++;
 	freePtr--;
     }    
