@@ -883,13 +883,11 @@ void CegoBufferPool::commitCheckpoint(unsigned tabSetId, CegoLockHandler *pLockH
 	{
 	    if ( needPageBackup(pageId) )
 	    {
+		
 #ifdef CGDEBUG
-		log(_modId, Logger::DEBUG, Chain("Saving page ") + Chain(bh.pageId) + Chain(" to log"));		
+		log(_modId, Logger::DEBUG, Chain("Saving page ") + Chain(pageId) + Chain(" to log"));
 #endif
-
-		log(_modId, Logger::NOTICE, Chain("Saving page ") + Chain(pageId) + Chain(" to log"));
-
-				
+		
 		unsigned ts;
 		unsigned oldFixStat;
 		char *oldPageData = new char[_pageSize];
