@@ -36,7 +36,7 @@ CegoCheckpoint::~CegoCheckpoint()
 {
 }
 
-bool CegoCheckpoint::checkpointReached(const Chain& tableSet, int interval)
+bool CegoCheckpoint::checkpointReached(const Chain& tableSet, unsigned interval)
 {
     // checkpointing disabled
     if ( interval == 0 )
@@ -52,7 +52,7 @@ bool CegoCheckpoint::checkpointReached(const Chain& tableSet, int interval)
 	    pCPE->setNextCP(ts.asLong() + interval);
 	    return true;
 	}
-	else if ( interval < (int)(pCPE->getNextCP() - ts.asLong()) )
+	else if ( interval < (unsigned)(pCPE->getNextCP() - ts.asLong()) )
 	{
 	    // if interval was reduced, we just set new interval
 	    pCPE->setNextCP(ts.asLong() + interval);
