@@ -8,7 +8,7 @@
 //      
 // Design and Implementation by Bjoern Lemke
 //
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
@@ -20,6 +20,6 @@
 //
 ///////////////////////////////////////////////////////////////////////////////
 
-enum CegoComparison { EQUAL, NOT_EQUAL, LESS_THAN, MORE_THAN, LESS_EQUAL_THAN, MORE_EQUAL_THAN };
+enum CegoComparison { EQUAL, LESS_THAN, MORE_THAN, LESS_EQUAL_THAN, MORE_EQUAL_THAN, NOT_EQUAL };
 
 #endif
