@@ -28,7 +28,7 @@
 #include <string.h>
 #include <stdlib.h>
 
-CegoCondition::CegoCondition(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
+CegoCondition::CegoCondition(char *buf, CegoQueryManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
 {
     _pLeft=0;
     _pRight=0;
@@ -154,7 +154,7 @@ void CegoCondition::encode(char *buf, CegoProcBlock *pBlock)
     }
 }
 
-void CegoCondition::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
+void CegoCondition::decode(char *buf, CegoQueryManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
 {
     if ( _pLeft ) 
 	delete _pLeft;
