@@ -999,3 +999,9 @@ void CegoDatabaseManager::getAggTCLockStat(Chain& lockGroup, unsigned& numLock,
 	}
     }
 }
+
+Chain CegoDatabaseManager::getTSTicket(const Chain& tableSet) const
+{
+    Chain tsTicket = getTSRoot(tableSet) + Chain("/") + tableSet + Chain("_ticket.xml"); 
+    return tsTicket;
+}
