@@ -27,7 +27,7 @@
 #include <lfcxml/XMLOutStream.h>
 
 // CEGO INCLUDES
-#include "CegoDistManager.h"
+#include "CegoQueryManager.h"
 #include "CegoAdminHandler.h"
 #include "CegoObjectCursor.h"
 #include "CegoField.h"
@@ -36,7 +36,7 @@ class CegoExpOutStream : public XMLOutStream {
     
 public:
     
-    CegoExpOutStream(unsigned tabSetId, const Chain& tableName, const ListT<CegoField>& schema, CegoDistManager* pGTM, CegoAdminHandler* pAH = 0);
+    CegoExpOutStream(unsigned tabSetId, const Chain& tableName, const ListT<CegoField>& schema, CegoQueryManager* pGTM, CegoAdminHandler* pAH = 0);
     ~CegoExpOutStream();
 
     unsigned long long numExported() const;
@@ -48,7 +48,7 @@ private:
 
     Element* getRowElement(ListT<CegoField>& schema);
     
-    CegoDistManager* _pGTM;
+    CegoQueryManager* _pGTM;
     CegoAdminHandler* _pAH;
     CegoObjectCursor* _pOC;
     ListT<CegoField> _schema;
