@@ -25,14 +25,14 @@
 #include <lfcbase/ListT.h>
 
 // CEGO INCLUDES
-#include "CegoDistManager.h"
+#include "CegoQueryManager.h"
 #include "CegoDbHandler.h"
 
 class CegoJDBCInfo {
 
 public:
 
-    CegoJDBCInfo(CegoDistManager* pTabMng, CegoDbHandler* pDbHandle);
+    CegoJDBCInfo(CegoQueryManager* pTabMng, CegoDbHandler* pDbHandle);
     ~CegoJDBCInfo();
 
     void handleRequest(const ListT<Chain>& argList) const;
@@ -41,7 +41,7 @@ private:
 
     void checkAccess() const;
 
-    CegoDistManager* _pTabMng;
+    CegoQueryManager* _pQueryMng;
     CegoDbHandler* _pDbHandle;  
 };
 #endif
