@@ -30,7 +30,7 @@
 #include <string.h>
 #include <stdlib.h>
 
-CegoPredicate::CegoPredicate(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
+CegoPredicate::CegoPredicate(char* buf, CegoQueryManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
 {
     _pExpr1 = 0;
     _pExpr2 = 0;
@@ -741,7 +741,7 @@ void CegoPredicate::encode(char *buf, CegoProcBlock *pBlock)
     }
 }
 
-void CegoPredicate::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
+void CegoPredicate::decode(char *buf, CegoQueryManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
 {
     char* pP = (char*)buf;
 
