@@ -309,18 +309,22 @@ void CegoQueryCursor::querySetup(ListT<CegoField>** pFLA, CegoPredicate* pPred)
     
     if (  pPred &&  ( _pCO->getType() == CegoObject::TABLE || _pCO->getType() == CegoObject::VIEW  || _pCO->getType() == CegoObject::ALIAS)  )
     {
+	
 	_pPropPred = pPred->getReduced(_tableAlias);
+	
 	_pJoinPred = _pPropPred;
     }
     else if ( pPred && _pCO->getType() == CegoObject::JOIN )
     {
-	// set up for further propagation
-	_pPropPred = pPred;
-	
+		
 	CegoJoinObject *pJO = (CegoJoinObject*)_pCO;
-	
-	// if ( pJO->getJoinType() == CegoJoinObject::INNER )
-	// {
+
+	// for inner joins, we propagate the predicate
+	if ( pJO->getJoinType() == CegoJoinObject::INNER )
+	{	    
+	    _pPropPred = pPred;
+	}
+
 	Chain leftAlias = pJO->getLeftObject()->getTabAlias();
 	
 	ListT<Chain> aliasList;
@@ -331,8 +335,7 @@ void CegoQueryCursor::querySetup(ListT<CegoField>** pFLA, CegoPredicate* pPred)
 	    ListT<Chain> subList = pJO->getSubAliasList();
 	    aliasList += subList;
 	}
-	
-	
+		
 	Chain rightAlias = pJO->getRightObject()->getTabAlias();
 	if ( pJO->getRightObject()->getType() != CegoObject::JOIN )
 	    aliasList.Insert(rightAlias);
@@ -412,6 +415,7 @@ void CegoQueryCursor::querySetup(ListT<CegoField>** pFLA, CegoPredicate* pPred)
     }
     else if ( _pCO->getType() == CegoObject::JOIN )
     {
+
 	CegoAttrCond attrCond;
 	joinSetup(attrCond);
     }
@@ -446,10 +450,14 @@ void CegoQueryCursor::querySetup( CegoAttrCond& attrCond, ListT<CegoField>** pFL
     else if ( pPred && _pCO->getType() == CegoObject::JOIN )
     {
 
-	// set up for further propagation
-	_pPropPred = pPred;
-	
 	CegoJoinObject *pJO = (CegoJoinObject*)_pCO;
+	
+	// for inner joins, we propagate the predicate
+
+	if ( pJO->getJoinType() == CegoJoinObject::INNER )
+	{	    
+	    _pPropPred = pPred;
+	}
 
 	Chain leftAlias = pJO->getLeftObject()->getTabAlias();
 	
@@ -477,6 +485,7 @@ void CegoQueryCursor::querySetup( CegoAttrCond& attrCond, ListT<CegoField>** pFL
 	if ( _pJoinPred )
 	    pPred->setChecked(true);
 
+    // setup field list array
     _pFLA = pFLA;
     
     if ( _pCO->getType() == CegoObject::VIEW )
@@ -501,6 +510,9 @@ void CegoQueryCursor::querySetup( CegoAttrCond& attrCond, ListT<CegoField>** pFL
 	    cout << "2. No condition for view " << _tableAlias << endl;
 	*/
 	
+	// if ( _pJoinPred )
+	//     cout << "JoinPred = " << _pJoinPred->toChain(0) << endl;
+	
 	if ( _pSelect->setViewCond(_tableAlias, attrCond, _pPropPred, pFLA) )
 	    _doEval=false;
 	else
@@ -511,11 +523,8 @@ void CegoQueryCursor::querySetup( CegoAttrCond& attrCond, ListT<CegoField>** pFL
 		     + Chain(_doEval));
 #endif
 
-	
 	_pSelect->prepare();
-
 	_pSelect->checkValidRef();
-
 	_cursorCond = attrCond;
     }
     else if ( _pCO->getType() == CegoObject::ALIAS )
@@ -583,7 +592,7 @@ void CegoQueryCursor::querySetup( CegoAttrCond& attrCond, ListT<CegoField>** pFL
     }
     else if ( _pCO->getType() == CegoObject::JOIN )
     {
-
+	
 #ifdef CGDEBUG
 	_pDBMng->log(_modId, Logger::DEBUG, Chain("Setting join condition ") + attrCond.toChain());	
 #endif
