@@ -37,24 +37,24 @@ class CegoTableCache {
     
 public:
     
-    CegoTableCache(int tabSetId, const Chain& cacheFilter, int maxSize, int maxEntry, int hashRange, CegoDatabaseManager *pDBMng);
+    CegoTableCache(unsigned tabSetId, const Chain& cacheFilter, unsigned maxSize, unsigned maxEntry, unsigned hashRange, CegoDatabaseManager *pDBMng);
     ~CegoTableCache();
 
     Element* getCacheInfo();
     Element* getCacheList();
     const Chain& getFilter() const;
     void setFilter(const Chain& cacheFilter);
-    int getMaxSize() const;
-    void setMaxSize(int maxSize);
-    int getUsedSize() const;
-    const int getNumTableCache() const;
+    unsigned getMaxSize() const;
+    void setMaxSize(unsigned maxSize);
+    unsigned getUsedSize() const;
+    const unsigned getNumTableCache() const;
     void invalidate(const Chain& tableName);
-    CegoFieldValue*** claimEntry(const Chain& tableName, int& numRow, int& numCol);
+    CegoFieldValue*** claimEntry(const Chain& tableName, unsigned& numRow, unsigned& numCol);
     void releaseEntry(const Chain& tableName);
     bool matchEntry(const Chain& tableName);
     bool addEntry(const Chain& tableName, ListT< ListT<CegoFieldValue> >* pCache);
     void clean();
-    void getTCLockStat(int& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay);
+    void getTCLockStat(unsigned& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay);
     
 private:
 
@@ -63,19 +63,19 @@ private:
     public:
 
 	TableCacheEntry();
-	TableCacheEntry(int tabSetId, const Chain& tableName);
-	TableCacheEntry(int tabSetId, const Chain& tableName, ListT< ListT<CegoFieldValue> >* pCacheList);
+	TableCacheEntry(unsigned tabSetId, const Chain& tableName);
+	TableCacheEntry(unsigned tabSetId, const Chain& tableName, ListT< ListT<CegoFieldValue> >* pCacheList);
 	~TableCacheEntry();
 
-	const int getSize() const;
+	const unsigned getSize() const;
 
-	int getHashPos(int hashSize) const;
+	unsigned getHashPos(unsigned hashSize) const;
 	
-	int getNumRows() const;
-	int getNumCols() const;
+	unsigned getNumRows() const;
+	unsigned getNumCols() const;
 
 	const Chain& getTableName() const;
-	int getTabSetId() const;
+	unsigned getTabSetId() const;
 
 	CegoFieldValue*** claimCache();
 	void releaseCache();
@@ -97,11 +97,11 @@ private:
     private:
 	
 	Chain _tableName;
-	int _tabSetId;
+	unsigned _tabSetId;
 	CegoFieldValue*** _pCacheArray;
-	int _numRow;
-	int _numCol;
-	int _numUsed;
+	unsigned _numRow;
+	unsigned _numCol;
+	unsigned _numUsed;
 	unsigned long _numHit;
 	
     };
@@ -110,13 +110,13 @@ private:
     void PW();
     void V();
     
-    int _tabSetId;
+    unsigned _tabSetId;
     Chain _cacheFilter;
-    int _maxEntry;
-    int _maxSize;
-    int _hashRange;
-    int _usedSize;
-    int _numFail;
+    unsigned _maxEntry;
+    unsigned _maxSize;
+    unsigned _hashRange;
+    unsigned _usedSize;
+    unsigned _numFail;
     CegoDatabaseManager* _pDBMng;
     HashT<TableCacheEntry>* _pTableCache;
     Matcher* _pTableFilter;
