@@ -26,14 +26,16 @@
 
 // cego includes
 #include "CegoDefs.h"
-#include "CegoTableManager.h"
 #include "CegoTableObject.h"
 #include "CegoQueryHelper.h"
+#include "CegoDataPointer.h"
+
 
 #define MAXTRANSACTION 30
 
 // forward declaration
 class CegoTableManager;
+class CegoDatabaseManager;
 
 class CegoTransactionManager {
     
