@@ -2924,7 +2924,7 @@ void CegoXMLSpace::setTSRoot(const Chain& tableSet, const Chain& tsRoot)
     V();
 }
 
-Chain CegoXMLSpace::getTSRoot(const Chain& tableSet)
+Chain CegoXMLSpace::getTSRoot(const Chain& tableSet) const
 {
     Chain tsRoot;
 
@@ -3182,33 +3182,6 @@ void CegoXMLSpace::doc2Xml()
     V();
 }
 
-void CegoXMLSpace::setTSTicket(const Chain& tableSet, const Chain& tsTicket)
-{
-    P();
-    Element *pTS = getTableSetElement(tableSet);
-
-    if ( pTS )
-    {
-	pTS->setAttribute(XML_TSTICKET_ATTR, tsTicket);
-    }
-    else
-    {
-	V();
-	Chain msg = "Unknown tableset <" + tableSet + ">"; 
-	throw Exception(EXLOC, msg);
-    }
-    V();
-}
-
-Chain CegoXMLSpace::getTSTicket(const Chain& tableSet)
-{
-    P();
-    Element *pE = getTableSetElement(tableSet);
-    Chain tsTicket = pE->getAttributeValue(XML_TSTICKET_ATTR);
-    V();
-    return tsTicket;
-}
-
 unsigned long long CegoXMLSpace::getTID(const Chain& tableSet)
 {
     P();
